@@ -1,4 +1,4 @@
-from lesscode.utils.doc.interface_doc_handler import swagger_json_project
+from lesscode.utils.doc.interface_doc import swagger_json_project
 from lesscode.web.base_handler import BaseHandler
 from lesscode.web.router_mapping import Handler, GetMapping
 from tornado.options import options
