@@ -2,21 +2,25 @@ import importlib
 
 from tornado.options import options
 
-util = None
-events = None
-try:
-    util = importlib.import_module("apscheduler.util")
-    events = importlib.import_module("apscheduler.events")
-except ImportError as e:
-    raise Exception(f"apscheduler is not exist,run:pip install apscheduler==3.9.1")
-
 
 class TaskHelper:
     @staticmethod
     def add_job(func, trigger=None, args=None, kwargs=None, id=None, name=None,
-                misfire_grace_time=util.undefined, coalesce=util.undefined, max_instances=util.undefined,
-                next_run_time=util.undefined, jobstore='default', executor='default',
+                misfire_grace_time=None, coalesce=None, max_instances=None,
+                next_run_time=None, jobstore='default', executor='default',
                 replace_existing=False, **trigger_args):
+        try:
+            util = importlib.import_module("apscheduler.util")
+        except ImportError:
+            raise Exception(f"apscheduler is not exist,run:pip install apscheduler==3.9.1")
+        if misfire_grace_time is None:
+            misfire_grace_time = util.undefined
+        if coalesce is None:
+            coalesce = util.undefined
+        if max_instances is None:
+            max_instances = util.undefined
+        if next_run_time is None:
+            next_run_time = util.undefined
         job = options.scheduler.add_job(func, trigger=trigger, args=args, kwargs=kwargs, id=id, name=name,
                                         misfire_grace_time=misfire_grace_time, coalesce=coalesce,
                                         max_instances=max_instances,
@@ -26,9 +30,21 @@ class TaskHelper:
 
     @staticmethod
     def scheduled_job(trigger, args=None, kwargs=None, id=None, name=None,
-                      misfire_grace_time=util.undefined, coalesce=util.undefined, max_instances=util.undefined,
-                      next_run_time=util.undefined, jobstore='default', executor='default',
+                      misfire_grace_time=None, coalesce=None, max_instances=None,
+                      next_run_time=None, jobstore='default', executor='default',
                       **trigger_args):
+        try:
+            util = importlib.import_module("apscheduler.util")
+        except ImportError:
+            raise Exception(f"apscheduler is not exist,run:pip install apscheduler==3.9.1")
+        if misfire_grace_time is None:
+            misfire_grace_time = util.undefined
+        if coalesce is None:
+            coalesce = util.undefined
+        if max_instances is None:
+            max_instances = util.undefined
+        if next_run_time is None:
+            next_run_time = util.undefined
         inner = options.scheduler.scheduled_job(trigger, args=args, kwargs=kwargs, id=id, name=name,
                                                 misfire_grace_time=misfire_grace_time, coalesce=coalesce,
                                                 max_instances=max_instances,
@@ -95,7 +111,13 @@ class TaskHelper:
         options.scheduler.remove_jobstore(alias=alias, shutdown=shutdown)
 
     @staticmethod
-    def add_listener(callback, mask=events.EVENT_ALL):
+    def add_listener(callback, mask=None):
+        try:
+            events = importlib.import_module("apscheduler.events")
+        except ImportError as e:
+            raise Exception(f"apscheduler is not exist,run:pip install apscheduler==3.9.1")
+        if mask is None:
+            mask = events.EVENT_ALL
         options.scheduler.add_listener(callback, mask=mask)
 
     @staticmethod
